@@ -1,4 +1,4 @@
 .onLoad <- function(libname, pkgname) {
   # CRAN OMP THREAD LIMIT
-  Sys.setenv("OMP_THREAD_LIMIT" = 2)
+  Sys.setenv(OMP_THREAD_LIMIT = 2)
 }
