@@ -2,33 +2,21 @@ test_that("attributes_means", {
   skip_if_not_installed("emmeans")
   model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
-  estim <- suppressMessages(estimate_means(model))
+  estim <- suppressMessages(estimate_means(model, backend = "emmeans"))
   expect_identical(attributes(estim)$by, "Species")
-  expect_null(attributes(estim)$fixed)
 
-  estim <- suppressMessages(estimate_means(model, fixed = "Sepal.Width"))
-  expect_identical(attributes(estim)$by, "Species")
-  expect_identical(attributes(estim)$fixed, "Sepal.Width")
-
-  estim <- suppressMessages(estimate_means(model, by = "all"))
+  estim <- suppressMessages(estimate_means(model, by = "all", backend = "emmeans"))
   expect_identical(attributes(estim)$by, c("Species", "Sepal.Width"))
 })
 
 
-
 test_that("attributes_contrasts", {
   skip_if_not_installed("emmeans")
   model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
-  estim <- suppressMessages(estimate_contrasts(model))
+  estim <- suppressMessages(estimate_contrasts(model, backend = "emmeans"))
   expect_identical(attributes(estim)$contrast, "Species")
   expect_null(attributes(estim)$by)
-  expect_null(attributes(estim)$fixed)
-
-  estim <- suppressMessages(estimate_contrasts(model, fixed = "Sepal.Width"))
-  expect_identical(attributes(estim)$contrast, "Species")
-  expect_identical(attributes(estim)$fixed, "Sepal.Width")
-  expect_null(attributes(estim)$modulate)
 })
 
 
