@@ -1,7 +1,7 @@
 skip_on_cran()
 skip_if_not_installed("curl")
 skip_if_offline()
-skip_if_not_installed("marginaleffects")
+skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 skip_if_not_installed("betareg")
 
 test_that("estimate_means for betareg", {
