@@ -1,5 +1,5 @@
 skip_if_not_installed("emmeans")
-skip_if_not_installed("marginaleffects")
+skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 skip_if_not_installed("mgcv")
 skip_if_not_installed("gamm4")
 
